@@ -103,7 +103,7 @@ class K3SController:
         return [NodeInfoDO(**info) for info in infos]
 
     @exception_class_dec(max_try=1)
-    def get_node_metas(self, cluster_name: str, timeout=30):
+    def get_node_metas(self, cluster_name: str, timeout=5):
         response=requests.get(f'{self.url}/node_metas/cluster_name/{cluster_name}', 
             headers=self.header, timeout=timeout)
         infos = json.loads(response.text)
@@ -238,6 +238,15 @@ class K3SController:
         self._check_error(response.status_code, infos)
         return [PodDO(**s) for s in infos]
 
+    @exception_class_dec(max_try=1)
+    def delete_pod(self, cluster_name:str, namespace_name:str, pod_name:str, timeout=5):
+        response=requests.delete(
+            f'{self.url}/pod/cluster_name/{cluster_name}/namespace_name/{namespace_name}/pod_name/{pod_name}', 
+            headers=self.header, timeout=timeout)
+        info = json.loads(response.text)
+        self._check_error(response.status_code, info)
+        return info
+
     @exception_class_dec(max_try=1)
     def upload_to_oss_from_pod(self, pod_oss_operation_info: PodOSSOperationInfoDO, timeout=1200):
         data = json.dumps(pod_oss_operation_info.to_json())
